## This script transfers Massechusetts historical aerial survey data into
## current US forest service standards. It populates the fields DCA1, DMG_TYPE2
## and SEVERITY1 from the original featureclass field COMMONNAME. 

import arcpy

# locate the geodatabase and make it the workspace
folder = r"I:\Administration\Emma_Tait\Massachusetts\MASS_Historic_ADS_test.gdb"
arcpy.env.workspace = folder
arcpy.env.overwriteoutput = True;

# set output filename
data = folder+"\\MA_Historical_ADS_MergeTest"

# identify fields needed in transfer and initialize cursor
fields = ["COMMONNAME", "DCA1", "DMG_TYPE1", "SEVERITY1"]
rows = arcpy.UpdateCursor(data, fields)

# for each row, check the value in commonname and populate the correct field
# with the correct value
for row in rows:
    if "%" in row.COMMONNAME:
        if "50%" in row.COMMONNAME or "25%" in row.COMMONNAME or "30%" in row.COMMONNAME or "Light" in row.COMMONNAME or "Moderate" in row.COMMONNAME or "Modrate" in row.COMMONNAME:
            row.SEVERITY = 1
        elif "Heavy" in row.COMMONNAME or "75%" in row.COMMONNAME:
            row.SEVERITY = 2
    if "Gypsy Moth" in row.COMMONNAME or row.COMMONNAME == "Gypsy" or "Gyspy Moth" in row.COMMONNAME:
        row.DCA1 = 12089
    elif "Oak Leaf Skeletonizer" in row.COMMONNAME or "Oak Leaf Skeltonizer" in row.COMMONNAME or row.COMMONNAME == "Oak Skeletonizer":
        row.DCA1 = 12029
    elif row.COMMONNAME == "Anthracnose":
        row.DCA1 = 25025
    elif row.COMMONNAME == "Apple Scab":
        row.DCA1 = 22089
    elif row.COMMONNAME == "Ash Rust":
        row.DCA1 = 25048
    elif row.COMMONNAME == "Beech Bark Disease":
        row.DCA1 = 22042

    #the row below is commented out because it unknown what the value should be translated to. 
##    elif row.COMMONNAME == "Beech Maple" or row.COMMONNAME = "Beech/Maple": #### Unknown Damage Type, probably defoliation according to workshop questionnaires but not positive
        
    elif row.COMMONNAME == "Beech Mortality":
        row.DMG_TYPE1 = 2
    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Birch":#### Unknown Damage Type, probably defoliation according to workshop questionnaires but not positive
        
    elif row.COMMONNAME == "Birch Leaf Miner":
        row.DCA1 = 12070
    elif row.COMMONNAME == "Black Locust Gall Midge":
        row.DCA1 = 12119 ## Actually Locust leafminer according to workshop worksheets
    elif row.COMMONNAME == "Black Turpintine Beetle" or row.COMMONNAME == "Black Turpingtine Beetle":
        row.DCA1 = 11011
    elif row.COMMONNAME == "Brown Dying Pine/Spruce" or row.COMMONNAME == "Browning" or row.COMMONNAME == "Brown Pine" or row.COMMONNAME == "Brown Pine White Spruce":
        row.DMG_TYPE1 = 3
    elif "Brown Tail" in row.COMMONNAME and (row.DCA1 == "" or row.DCA1 == None):
        row.DCA1 = 12068
    elif "Brown Tail" in row.COMMONNAME and (row.DCA1 != "" or row.DCA1 != None):
        row.DCA2 = 12068
    elif row.COMMONNAME == "Canker":
        row.DCA1 = 22700       
    elif "Cankerworm" in row.COMMONNAME or row.COMMONNAME == "Fall Canker Worm" or row.COMMONNAME == "Fall Cankerworm" and (row.DCA1 == "" or row.DCA1 == None):
        row.DCA1 = 12014
    elif "Cankerworm" in row.COMMONNAME or row.COMMONNAME == "Fall Canker Worm" or row.COMMONNAME == "Fall Cankerworm" and (row.DCA1 != "" or row.DCA1 != None):
        row.DCA2 = 12014
    elif row.COMMONNAME == "Change in Water Table":
        row.DCA1 = 50004
    elif row.COMMONNAME == "Cherry Scallop Shell Moth":
        row.DCA1 = 12081
    elif row.COMMONNAME == "Cieada":
        row.DCA1 = 13006
    elif row.COMMONNAME == "Dead & Dying Pine - Spruce" or row.COMMONNAME == "Dead & Rotting Oaks" or row.COMMONNAME == "Dead Hemlock" or "Dead Oak" in row.COMMONNAME or "Dead Pine" in row.COMMONNAME or row.COMMONNAME == "Dead Spruce" or row. COMMONNAME == "Dead Timber" or row.COMMONNAME == "Dead Trees" or "Dead/Dying" in row.COMMONNAME:
        row.DMG_TYPE1 = 2
    elif row.COMMONNAME == "Dead Trees (Flooded)":
        row.DCA1 = 50004
        row.DMG_TYPE1 = 2
    elif row.COMMONNAME == "Defoliated Softwoods":
        row.DMG_TYPE1 = 2
    elif row.COMMONNAME == "Diplodia" or row.COMMONNAME == "Diplodia (Pine)" or row.COMMONNAME == "Dipoldia":
        row.DCA1 = 25058
    elif row.COMMONNAME == "Drought" or row.COMMONNAME == "Drought (Beech)":
        row.DCA1 = 50003
##    elif "Dying" in row.COMMONNAME:## THIS CAN'T JUST BE DYING, HAS TO BE MORE SPECIFIC B/C IS DISCOLORATION
        #NOT MORTALITY

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Evergreen Growth": ##
    elif "Fire" in row.COMMONNAME: #includes "Fire / Chemical Dump Site"
        row.DCA1 = 30000
    elif row.COMMONNAME == "Flooding":
        row.DCA1 = 50004
    elif "Forest Tent" in row.COMMONNAME:
        row.DCA1 = 12096

    #the rows below are commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Fuzzy Tops": ##
    #elif row.COMMONNAME == "Heavy Hemlock Mortality" or row.COMMONNAME == "Gypsy Moth-Heavy Mortality":
##    elif row.COMMONNAME == "Hemlock": ##
    elif row.COMMONNAME == "Hemlock Looper":
        row.DCA1 = 12083

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Housing Development":
        
    elif row.COMMONNAME == "Insect":
        row.DCA1 = 10000

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Larch":
    elif row.COMMONNAME == "Linden Looper":
        row.DCA1 = 12067
    elif row.COMMONNAME == "Locust Leafminer" or row.COMMONNAME == "Locust Leaf Roller" or row.COMMONNAME == "Locust Leaf Ruller" or row.COMMONNAME == "Locust Twig Borer":
        row.DCA1 = 12119
    elif "Logging" in row.COMMONNAME:
        row.DCA1 = 70007
    elif row.COMMONNAME == "Looper" or row.COMMONNAME == "Looper/Light":
        row.DCA1 = 12083
    elif row.COMMONNAME == "Maple Saddled Prominet":
        row.DCA1 = 12079

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Miner": ###
    elif row.COMMONNAME == "Nantucket Pine Moth":
        row.DCA1 = 15065 #Nantucket Pine Tip Moth
    elif row.COMMONNAME == "Needle Miner":
        row.DCA1 = 12004 #General Needleminers

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "No Cause": ######
##    elif row.COMMONNAME == "Not Defoliated": ###
##    elif row.COMMONNAME == "Oak": ##
##    elif row.COMMONNAME == "Oak Leaf": ####
##    elif row.COMMONNAME == "Oak Leaf Minor":###
        
    elif "Oak Leaf Tier" in row.COMMONNAME:
        row.DCA1 = 12055
    elif "Off Color" in row.COMMONNAME:
        row.DMG_TYPE1 = 1
    elif row.COMMONNAME == "Pear Thrips":
        row.DCA1 = 14058

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Pine" or row.COMMONNAME == "Pine - Unknown" or row.COMMONNAME == "Pine/Unknown":
    elif row.COMMONNAME == "Pine Heavy Mortality":
        row.SEVERITY = 2
        row.DMG_TYPE1 = 2
    elif row.COMMONNAME == "Pine Looper":
        row.DCA1 = 12174
    elif row.COMMONNAME == "Pine Needle Miner":
        row.DCA1 = 12069
    elif "Pine Tip" in row.COMMONNAME:
        row.DCA1 = 15065 #assumed this was the same type of pine tip moth as the nantucket pine tip moth
    elif row.COMMONNAME == "Pine Pitch Looper":
        row.DCA1 = 12174

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Red Maple Thin Foliage" or row.COMMONNAME = "Red Maple Thin Foliage No Caus":
    elif row.COMMONNAME == "Red Spruce Winter Inj.":
        row.DCA1 = 50014 
    elif row.COMMONNAME == "Rusty Pine Hard Defoliation":
        row.SEVERITY = 2
        row.DMG_TYPE1 = 1
    elif row.COMMONNAME == "Saddle Priminet" or row.COMMONNAME == "Saddle Prominent" or row.COMMONNAME == "Saddle Prominet" or row.COMMONNAME == "Saddled Prominent":
        row.DCA1 = 12079
    elif row.COMMONNAME == "Satin Moth":
        row.DCA1 = 12086

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Skeletonizer": ###
##    elif row.COMMONNAME == "Sprayed Area": ##
##    elif row.COMMONNAME == "Spruce": ###
        
    elif row.COMMONNAME == "Spruce Gall Adelgid":
        row.DCA1 = 17002
    elif row.COMMONNAME == "Storm Damage":
        row.DCA1 = 50000 ## this is just the code for abiotic damage, i'm not sure if it is flooding or wind or something else

    #the row below is commented out because it unknown what the value should be translated to.
##    elif row.COMMONNAME == "Swamp":
##    elif row.COMMONNAME == "Thin Crowns":
        
    elif row.COMMONNAME == "Tier":
        row.DCA1 = 12055
    elif row.COMMONNAME == "Turp Beetle":
        row.DCA1 = 11011
    elif "Unknown" in row.COMMONNAME and (row.DCA1 == "" or row.DCA1 == None):
        row.DCA1 = 99999
    elif "Unknown" in row.COMMONNAME and (row.DCA1 != "" or row.DCA1 != None):
        row.DCA2 = 99999
    elif row.COMMONNAME == "Willow Leaf Beetle":
        row.DCA1 = 12215
    if "Defoliation" in row.COMMONNAME:
        row.DMG_TYPE1 = 1

    # Commit row update
    rows.updateRow(row)

    
        
