## This script standardizes the historical aerial survey data for ME into
## current Federal standards. It adds fields for severity of damage, damage
## type and state and then populates those fields according to values in
## existing fields in teh input feature class.

import arcpy

#function to calculate severity based on the value in the DEFOL field in the
#original feature class. For Maine, anything containing low or light or just
#medium was mapped to low while anything with medium-heavy or heavy was mapped
#to high. 
def severity (r, row):
    if r=="medium" or r=="Moderate" or r=="Medium":
        row.SEVERITY1 = 1
    elif ((("Heavy" or "Severe" or "Medium" or "Moderate" or "high") in r) and ("Light" or "low")not in r): #and (row.SEVERITY1 == "" or row.SEVERITY1 == " " or row.SEVERITY1 == None:
        row.SEVERITY1 = 2
    else:
        row.SEVERITY1 = 1

#location of geodatabase
folder=r"I:\Administration\Emma_Tait\Maine\ME_Historical_ADS_test.gdb";
arcpy.env.workspace=folder
arcpy.env.overwriteOutput = True

#aggregated file
data = folder + "\\ME_Historical_aggregated"
fields=["Defol","LEVEL"]
rows = arcpy.UpdateCursor(data,fields)

#add fields for damage type, severity and state
arcpy.AddField_management(data, "SEVERITY1", "SHORT")
arcpy.AddField_management(data, "DMG_TYPE1", "SHORT")
arcpy.AddField_management(data, "STATE", "TEXT")

#add state and damage type (damage type is 1 because of field name Defol and
#original file name containing word defoliation)
arcpy.CalculateField_management(data, "STATE", '"ME"')
arcpy.CalculateField_management(data, "DMG_TYPE1",1)

#get year from fields  
for row in rows:
    if row.Year != None:
        row.RPT_YR = row.Year
    elif row.Y94 == 1:
        row.RPT_YR = 1994
    elif row.Y95 == 1:
        row.RPT_YR = 1995
    elif row.Y96 == 1:
        row.RPT_YR = 1996
    elif row. Y97 == 1:
        row.RPT_YR = 1997
        
    # if Defol row is not empty calculate severity based on its value
    if row.Defol != "" and row.Defol != " " and row.Defol != None:
        severity(row.Defol, row)
        
    # if LEVEL row is not empty calculate severity based on its value
    elif row.LEVEL != "" and row.LEVEL != " " and row.LEVEL != None: #(row.Defol == None or row.Defol == "" or row.Defol == " ") and
        severity(row.LEVEL, row)

    # if neither of the above is true than there is no severity value
    else:
        row.SEVERITY1 = -1

    # commit the row updates
    rows.updateRow(row)
    
    

