## This script converts the historical New Hampshire ADS data to the current
## US forest service standards. it adds fields for Damage Causal Agent (DCA1)
## and for Severity (SEVERITY1). It then populates these fields with data from
## fields in the original dataset

import arcpy

#function to populate severity column. This needs to be modified once we find out
#what the other codes are
def severity(r, row): 
    if r == "L" or r == "M" or r=="m" or r=="l" or r=="LM":
        row.SEVERITY1=1
    elif r=="H" or r=="h":
        row.SEVERITY1=2
    else:
        row.SEVERITY1=-1

# location of the geodatabase and make this the workspace
folder=r"I:\WorkingProjects\ForestHealthAtlas\New_Hampshire\NH_Historical_ADS.gdb";
arcpy.env.workspace=folder

# get the list of files in the database
files=arcpy.ListFeatureClasses("*")
arcpy.env.overwriteOutput = True;

# specify the output featureclass name. List the fields needed for the data transfer
data=folder+"\\NH_Historical_aggregated"

##if damage agent row is not empty put appropriate agent code into DCA1
arcpy.AddField_management(data, "DCA1","LONG")
arcpy.AddField_management(data,"SEVERITY1","SHORT")
arcpy.AddField_management(data,"DMG_TYPE1","SHORT")
fields=["DEFO_GM", "DEFO_SP", "DEFO_SB", "DEFO_HL", "DEFO_BLM", "DEFO_CSM", "DEFO_LLM", "DEFO_SMDIE", "DEFO_ANTHR", "DEFO_HDIE", "DEFO_RSB", "DEFO_WI", "DEFO_ELB", "DEFO_HAIL", "DEFO_SDD","DCA1", "SEVERITY1","DMG_TYPE1"]

# initialize cursor for row transfer
rows = arcpy.UpdateCursor(data,fields)

#look at all of the damage agent columns, if they are populated, put the correct
#damage agent in DCA1 and calculate the severity. 
for row in rows:
    row.DMG_TYPE1=1
    if row.DEFO_GM != "" and row.DEFO_GM != "None" and row.DEFO_GM != " " and row.DEFO_GM != None:
        row.DCA1 = 12089 #gypsy moth
        severity(row.getValue("DEFO_GM"),row)
    elif row.DEFO_SP != "" and row.DEFO_SP != "None" and row.DEFO_SP != " " and row.DEFO_SP != None:
        row.DCA1=12079 #saddled prominent
        severity(row.DEFO_SP,row)
    elif row.DEFO_SB != "" and row.DEFO_SB != "None" and row.DEFO_SB != " " and row.DEFO_SB != None:
        row.DCA1 = 12038 #spruce budworm
        severity(row.DEFO_SB,row)
    elif row.DEFO_HL != "" and row.DEFO_HL != "None" and row.DEFO_HL != " " and row.DEFO_HL != None:
        row.DCA1 = 12083 #hemlock looper
        severity(row.DEFO_HL,row)
    elif row.DEFO_BLM != "" and row.DEFO_BLM != "None" and row.DEFO_BLM != " " and row.DEFO_BLM != None: #listed in vt as blight... not sure if this is correct
        row.DCA1=12070 #Birch leaf miner
        severity(row.DEFO_BLM,row)
    elif row.DEFO_CSM != "" and row.DEFO_CSM != "None" and row.DEFO_CSM != " " and row.DEFO_CSM != None:
        row.DCA1=12081 #cherry scallop moth
        severity(row.DEFO_CSM,row)
    elif row.DEFO_LLM != "" and row.DEFO_LLM != "None" and row.DEFO_LLM != " " and row.DEFO_LLM != None:
        row.DCA1=12119 #locust leafminer
        severity(row.DEFO_LLM,row)
    elif row.DEFO_SMDIE != "" and row.DEFO_SMDIE != "None" and row.DEFO_SMDIE != " " and row.DEFO_SMDIE != None:
        row.DCA1=99999 #Sugar maple dieback, but code unknown
        severity(row.DEFO_SMDIE,row)
    elif row.DEFO_ANTHR != "" and row.DEFO_ANTHR != "None" and row.DEFO_ANTHR != " " and row.DEFO_ANTHR != None:
        row.DCA1 = 25025 #anthracnose
        severity(row.DEFO_ANTHR,row)
    elif row.DEFO_HDIE != "" and row.DEFO_HDIE != "None" and row.DEFO_HDIE != " " and row.DEFO_HDIE != None:
        row.DCA1=99999 #Hemlock dieback, but code unknown
        severity(row.DEFO_HDIE,row)
    elif row.DEFO_RSB != "" and row.DEFO_RSB != "None" and row.DEFO_RSB != " " and row.DEFO_RSB != None:
        row.DCA1=99999 #unknown
        severity(row.DEFO_RSB,row)
    elif row.DEFO_WI != "" and row.DEFO_WI != "None" and row.DEFO_WI != " " and row.DEFO_WI != None:
        row.DCA1=50014 #winter injury
        severity(row.DEFO_WI,row)
    elif row.DEFO_ELB != "" and row.DEFO_ELB != "None" and row.DEFO_ELB != " " and row.DEFO_ELB != None:
        row.DCA1=12141 #elm leaf beetle
        severity(row.DEFO_ELB,row)
    elif row.DEFO_HAIL != "" and row.DEFO_HAIL != "None" and row.DEFO_HAIL != " " and row.DEFO_HAIL != None:
        row.DCA1=50006 #hail
        severity(row.DEFO_HAIL,row)
    elif row.DEFO_SDD != "" and row.DEFO_SDD != "None" and row.DEFO_SDD != " " and row.DEFO_SDD != None:
        row.DCA1=50001 #air pollutants
        severity(row.DEFO_SDD,row)
    else:
        row.DCA1 = 99999 #unknown
        row.SEVERITY1=-1

    # commit row update
    rows.updateRow(row)

        

   
        
    
